@@ -18,6 +18,7 @@
 
 #include <QCoroTask>
 
+#include "FlatpakRefreshAppstreamMetadataJob.h"
 #include "flatpak-helper.h"
 
 class FlatpakSourcesBackend;
@@ -34,6 +35,7 @@ namespace Utils
 {
 /// Useful for when libflatpak returns strings that need to be freed
 QString copyAndFree(char *str);
+class ProgressCollector;
 }
 
 class FlatpakBackend : public AbstractResourcesBackend
@@ -111,13 +113,14 @@ private:
     {
         return m_installations.constFirst();
     }
-    QSharedPointer<FlatpakSource> integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote);
+    QSharedPointer<FlatpakSource> integrateRemote(GLibHolder<FlatpakInstallation> flatpakInstallation, GLibHolder<FlatpakRemote> remote);
     FlatpakResource *getRuntimeForApp(FlatpakResource *resource) const;
     FlatpakResource *resourceForComponent(const AppStream::Component &component, const QSharedPointer<FlatpakSource> &source) const;
     void checkRepositories(const QMap<QString, QStringList> &repositories);
 
     void loadAppsFromAppstreamData();
     bool loadAppsFromAppstreamData(FlatpakInstallation *flatpakInstallation);
+    void loadLocalUpdates();
     void loadLocalUpdates(FlatpakInstallation *flatpakInstallation);
     bool setupFlatpakInstallations(GError **error);
     void updateAppInstalledMetadata(FlatpakInstalledRef *installedRef, FlatpakResource *resource);
@@ -153,4 +156,7 @@ private:
     QVector<QSharedPointer<FlatpakSource>> m_flatpakLoadingSources;
     QSharedPointer<FlatpakSource> m_localSource;
     QTimer *const m_checkForUpdatesTimer;
+
+    friend class Utils::ProgressCollector;
+    Utils::ProgressCollector *const m_collector;
 };
